###############################################################################
# Objective: Polynomial
# Constraints: Simple bounds
###############################################################################
#  Watson set of SIP problems
#   As described by G.A. Watson in "Numerical Experiments with Globally
#                 Convergent Methods for Semi-Infinite Programming Problems",
#   Edited in Fiacco, A.V., and K.O. Kortanek (eds.),
#    "Semi-infinite Programming and Applications",
#    Lecture notes in Economics and Mathematical Systems no. 215, pp.193-205
#    Springer Verlag, Berlin (1983)
#
#   Example 2
#    Coded by A. Ismael F. Vaz 24/12/1999  aivaz@dps.uminho.pt
#    University of Minho, Portugal
#
# Adapted for multilocal optimization by A. Ismael F. Vaz 14/04/2004
#
# This is a regular (finite) optimization problem ...
#
###############################################################################

param nx;
param nt;

param x{1..nx};

var t {1..nt};

maximize ft:
	(1-x[1]^2*t[1]^2)^2-x[1]*t[1]^2-x[2]^2+x[2];

subject to bounds:
	0 <= t[1] <= 1;

data;

param nx := 2;
param nt := 1;

param x :=
	1 -0.75
	2  1.618034;

option solver mlocpsoa;
solve;

##################
# Solution found #
##################
printf "Solution found\n";
display t;
display ft;
